
///////////////////////////////////////////////////////////////////////////
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the version 3 of the GNU General Public License //
// as published by the Free Software Foundation.                         //
//                                                                       //
// This program is distributed in the hope that it will be useful, but   //
// WITHOUT ANY WARRANTY; without even the implied warranty of            //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      //
// General Public License for more details.                              //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program. If not, see <http://www.gnu.org/licenses/>.  //
//                                                                       //
// Written by Francois Fleuret                                           //
// (C) Idiap Research Institute                                          //
//                                                                       //
// Contact <francois.fleuret@idiap.ch> for comments & bug reports        //
///////////////////////////////////////////////////////////////////////////

#include "gaussian.h"

Gaussian::Gaussian() {
  _nb_samples = 0;
  _sum = 0.0;
  _sum_sq = 0.0;
}

void Gaussian::add_sample(scalar_t x) {
  _nb_samples++;
  _sum += x;
  _sum_sq += x * x;
}

scalar_t Gaussian::expectation() {
  return _sum / scalar_t(_nb_samples);
}

scalar_t Gaussian::variance() {
  scalar_t e = _sum / scalar_t(_nb_samples);
  return (_sum_sq - _sum * e) / scalar_t(_nb_samples - 1);
}

scalar_t Gaussian::standard_deviation() {
  return sqrt(variance());
}

